@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: buildhash.c,v 1.67 2000/08/22 10:52:25 geoff Exp $";
+    "$Id: buildhash.c,v 1.70 2001/07/25 21:51:45 geoff Exp $";
 #endif
 
 #define MAIN
@@ -10,7 +10,7 @@ static char Rcs_Id[] =
  *
  * Pace Willisson, 1983
  *
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,10 +26,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -49,6 +55,16 @@ static char Rcs_Id[] =
 
 /*
  * $Log: buildhash.c,v $
+ * Revision 1.70  2001/07/25 21:51:45  geoff
+ * Minor license update.
+ *
+ * Revision 1.69  2001/07/23 20:24:02  geoff
+ * Update the copyright and the license.
+ *
+ * Revision 1.68  2001/06/14 09:11:11  geoff
+ * Use a non-conflicting macro for bcopy to avoid compilation problems on
+ * smarter compilers.
+ *
  * Revision 1.67  2000/08/22 10:52:25  geoff
  * Fix a whole bunch of signed/unsigned compiler warnings.
  *
@@ -481,7 +497,7 @@ VOID * myrealloc (ptr, size, oldsize)
     nptr = mymalloc (size);
     if (nptr == NULL)
 	return NULL;
-    (void) bcopy (ptr, nptr, oldsize);
+    (void) BCOPY (ptr, nptr, oldsize);
     return nptr;
     }
 
