@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: correct.c,v 1.74 2001/06/10 23:54:56 geoff Exp $";
+    "$Id: correct.c,v 1.77 2001/07/25 21:51:47 geoff Exp $";
 #endif
 
 /*
@@ -11,7 +11,7 @@ static char Rcs_Id[] =
  *
  * Copyright (c), 1983, by Pace Willisson
  *
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -50,6 +56,16 @@ static char Rcs_Id[] =
 
 /*
  * $Log: correct.c,v $
+ * Revision 1.77  2001/07/25 21:51:47  geoff
+ * Minor license update.
+ *
+ * Revision 1.76  2001/07/23 20:24:03  geoff
+ * Update the copyright and the license.
+ *
+ * Revision 1.75  2001/06/14 09:11:11  geoff
+ * Use a non-conflicting macro for bcopy to avoid compilation problems on
+ * smarter compilers.
+ *
  * Revision 1.74  2001/06/10 23:54:56  geoff
  * Fix an ask-mode bug that could cause hangs.
  *
@@ -1422,7 +1438,7 @@ static void save_root_cap (word, pattern, prestrip, preadd, sufstrip, sufadd,
 		{
 		/* Followcase is the tough one. */
 		p = strtosichar (dent->word, 1);
-		(void) bcopy ((char *) (p + prestrip),
+		(void) BCOPY ((char *) (p + prestrip),
 		  (char *) (newword + preadd),
 		  (len - prestrip - sufstrip) * sizeof (ichar_t));
 		if (myupper (p[prestrip]))
