@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: defmt.c,v 1.55 2000/08/22 10:52:25 geoff Exp $";
+    "$Id: defmt.c,v 1.58 2001/08/01 22:15:56 geoff Exp $";
 #endif
 
 /*
@@ -11,7 +11,7 @@ static char Rcs_Id[] =
  *
  * Copyright (c), 1983, by Pace Willisson
  *
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -54,6 +60,21 @@ static char Rcs_Id[] =
 
 /*
  * $Log: defmt.c,v $
+ * Revision 1.58  2001/08/01 22:15:56  geoff
+ * When processing quoted strings inside HTML tags, don't handle
+ * ampersand sequences unless the quoted string is being spell-checked.
+ * That way, ampersands inside HREF links won't confuse the deformatter,
+ * but ampersand sequence inside ALT= tags will be handled correctly.
+ * Also, when skipping ampersand sequences inside quoted strings, give up
+ * the search for the semicolon if the closing quote is hit.  This change
+ * makes us a bit more robust in the fact of HTML syntax errors.
+ *
+ * Revision 1.57  2001/07/25 21:51:47  geoff
+ * Minor license update.
+ *
+ * Revision 1.56  2001/07/23 20:24:03  geoff
+ * Update the copyright and the license.
+ *
  * Revision 1.55  2000/08/22 10:52:25  geoff
  * Fix a whole bunch of signed/unsigned compiler warnings.
  *
@@ -328,12 +349,36 @@ static unsigned char * skiptoword (bufp) /* Skip to beginning of a word */
 	     * being string characters, because the isstringch() test
 	     * above would have already broken us out of the enclosing
 	     * loop in that case.
-	    */
+	     *
+	     * A complication is that quoted entities are only
+	     * interpreted in some quoted strings.  For example,
+	     * they're valid in ALT= tags but not in HREF tags, where
+	     * ampersands have an entirely different meaning.  We deal
+	     * with the problem by only interpreting HTMLSPECSTART if
+	     * we are checking the quoted string.
+	     */
 	    else if ((insidehtml & HTML_IN_SPEC) != 0
-	      ||  *bufp == HTMLSPECSTART)
+	      ||  (*bufp == HTMLSPECSTART
+		&&  ((insidehtml & HTML_CHECKING_QUOTE)
+		  ||  (insidehtml & HTML_IN_QUOTE) == 0)))
 		{
 		while (*bufp != HTMLSPECEND  &&  *bufp != '\0')
+		    {
+		    if ((insidehtml & HTML_IN_QUOTE)  &&  *bufp == HTMLQUOTE)
+			{
+			/*
+			 * The quoted string ended before the
+			 * ampersand sequence finished.  The HTML is
+			 * probably incorrect, but it would be a
+			 * mistake to keep skipping until we reach the
+			 * next random semicolon.  Instead, just stop
+			 * skipping right here.
+			 */
+			insidehtml &= ~(HTML_IN_QUOTE | HTML_CHECKING_QUOTE);
+			break;
+			}
 		    bufp++;
+		    }
 		if (*bufp == '\0')
 		    insidehtml |= HTML_IN_SPEC;
 		else
