@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: ispell.c,v 1.148 2001/05/30 21:14:47 geoff Exp $";
+    "$Id: ispell.c,v 1.152 2001/07/25 21:51:46 geoff Exp $";
 #endif
 
 #define MAIN
@@ -10,7 +10,7 @@ static char Rcs_Id[] =
  *
  * Copyright (c), 1983, by Pace Willisson
  *
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,10 +26,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -49,6 +55,19 @@ static char Rcs_Id[] =
 
 /*
  * $Log: ispell.c,v $
+ * Revision 1.152  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.151  2001/07/23 20:24:03  geoff
+ * Update the copyright and the license.
+ *
+ * Revision 1.150  2001/07/19 07:01:46  geoff
+ * Fix a bug that effectively disabled the -w switch.
+ *
+ * Revision 1.149  2001/06/14 09:11:11  geoff
+ * Use a non-conflicting macro for bzero to avoid compilation problems on
+ * smarter compilers.
+ *
  * Revision 1.148  2001/05/30 21:14:47  geoff
  * Invert the fcntl/mkstemp options so they will default to being used.
  *
@@ -240,7 +259,7 @@ static void initckch (wchars)
 	}
     if (wchars != NULL)
 	{
-	while (Trynum < SET_SIZE  &&  *wchars != '\0')
+	while (Trynum < SET_SIZE + MAXSTRINGCHARS  &&  *wchars != '\0')
 	    {
 	    if (*wchars != 'n'  &&  *wchars != '\\')
 		{
@@ -1226,7 +1245,7 @@ static void expandmode (option)
 	(void) fputs (buf, stdout);
 	if (flagp != NULL)
 	    {
-	    (void) bzero ((char *) mask, sizeof (mask));
+	    (void) BZERO ((char *) mask, sizeof (mask));
 	    while (*flagp != '\0'  &&  *flagp != '\n')
 		{
 		temp = CHARTOBIT ((unsigned char) *flagp);
