@@ -1,9 +1,9 @@
 /*
- * $Id: ispell.h,v 1.78 2000/08/22 10:52:25 geoff Exp $
+ * $Id: ispell.h,v 1.80 2001/07/25 21:51:46 geoff Exp $
  */
 
 /*
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -19,10 +19,16 @@
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -42,6 +48,12 @@
 
 /*
  * $Log: ispell.h,v $
+ * Revision 1.80  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.79  2001/07/23 20:24:03  geoff
+ * Update the copyright and the license.
+ *
  * Revision 1.78  2000/08/22 10:52:25  geoff
  * Fix a whole bunch of signed/unsigned discrepancies.
  *
