@@ -1,7 +1,7 @@
 /*
- * $Id: msgs.h,v 1.36 1999/01/07 01:58:14 geoff Exp geoff $
+ * $Id: msgs.h,v 1.40 2001/07/25 21:51:47 geoff Exp $
  *
- * Copyright 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -17,10 +17,16 @@
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -65,6 +71,18 @@
 
 /*
  * $Log: msgs.h,v $
+ * Revision 1.40  2001/07/25 21:51:47  geoff
+ * *** empty log message ***
+ *
+ * Revision 1.39  2001/07/23 22:11:08  geoff
+ * *** empty log message ***
+ *
+ * Revision 1.38  2001/07/23 20:43:37  geoff
+ * *** empty log message ***
+ *
+ * Revision 1.37  2000/11/14 07:27:04  geoff
+ * *** empty log message ***
+ *
  * Revision 1.36  1999/01/07 01:58:14  geoff
  * Update the copyright.
  *
@@ -284,8 +302,7 @@
 /*
  * The following strings are used in tgood.c:
  */
-#define TGOOD_C_TOO_MANY_PRE	"ispell:  Too many expansions in gen_pre_expansions\n"
-#define TGOOD_C_TOO_MANY_SUF	"ispell:  Too many expansions in gen_suf_expansions\n"
+#define TGOOD_C_NO_SPACE	"Out of memory while generating expansions"
 
 /*
  * The following strings are used in tree.c:
