@@ -1,10 +1,10 @@
 #ifndef lint
 static char Rcs_Id[] =
-	"$Id: makedent.c,v 1.52 2000/08/22 10:52:25 geoff Exp $";
+	"$Id: makedent.c,v 1.55 2001/07/25 21:51:46 geoff Exp $";
 #endif
 
 /*
- * Copyright 1988, 1989, 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1988, 1989, 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -20,10 +20,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -43,6 +49,16 @@ static char Rcs_Id[] =
 
 /*
  * $Log: makedent.c,v $
+ * Revision 1.55  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.54  2001/07/23 20:24:04  geoff
+ * Update the copyright and the license.
+ *
+ * Revision 1.53  2001/06/14 09:11:11  geoff
+ * Use a non-conflicting macro for bzero to avoid compilation problems on
+ * smarter compilers.
+ *
  * Revision 1.52  2000/08/22 10:52:25  geoff
  * Fix a whole bunch of signed/unsigned discrepancies.
  *
@@ -153,7 +169,7 @@ int makedent (lbuf, lbuflen, d)
     d->next = NULL;
     /* WARNING:  flagfield might be the same as mask! See ispell.h. */
     d->flagfield = 0;
-    (void) bzero ((char *) d->mask, sizeof (d->mask));
+    (void) BZERO ((char *) d->mask, sizeof (d->mask));
     d->flagfield |= USED;
     d->flagfield &= ~KEEP;
 
