@@ -1,10 +1,10 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: tgood.c,v 1.39 2000/11/14 07:27:04 geoff Exp $";
+    "$Id: tgood.c,v 1.42 2001/07/25 21:51:46 geoff Exp $";
 #endif
 
 /*
- * Copyright 1987-1989, 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1987-1989, 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -20,10 +20,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -49,6 +55,20 @@ static char Rcs_Id[] =
 
 /*
  * $Log: tgood.c,v $
+ * Revision 1.42  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.41  2001/07/23 22:09:15  geoff
+ * Change the expansion code so that the scratch table is allocated
+ * dynamically.  This cures a bug that caused munchlist to fail for
+ * languages that used affixes to encode parts of speech, rather than
+ * string transformations, and generated huge numbers of affixes.  While
+ * fixing this bug, I also eliminated an obsolete unused parameter from
+ * several functions.
+ *
+ * Revision 1.40  2001/07/23 20:24:04  geoff
+ * Update the copyright and the license.
+ *
  * Revision 1.39  2000/11/14 07:27:04  geoff
  * Use messages from msgs.h for the "too many expansions" errors.
  *
@@ -119,18 +139,19 @@ static void	suf_list_chk P ((ichar_t * word, ichar_t * ucword, int len,
 		  int ignoreflagbits, int allhits));
 int		expand_pre P ((unsigned char * croot, ichar_t * rootword,
 		  MASKTYPE mask[], int option, unsigned char * extra));
-static int	gen_pre_expansion P ((unsigned char * croot,
-		  ichar_t * rootword, struct flagent * flent, MASKTYPE mask[],
-		  char exptable[MASKBITS][], int numexpansions));
+static int	gen_pre_expansion P ((ichar_t * rootword,
+		  struct flagent * flent, MASKTYPE mask[],
+		  char *** exptable, int * exptsize, int numexpansions));
+static void	expand_exptable P ((char *** exptable, int * exptsize));
 int		expand_suf P ((unsigned char * croot, ichar_t * rootword,
 		  MASKTYPE mask[], int optflags, int option,
 		  unsigned char * extra));
-int		expand_suf_into_table P ((unsigned char * croot,
-		  ichar_t * rootword, MASKTYPE mask[], int optflags,
-		  char exptable[MASKBITS][], int numexpansions));
-static int	gen_suf_expansion P ((unsigned char * croot,
-		  ichar_t * rootword, struct flagent * flent,
-		  char exptable[MASKBITS][], int numexpansions));
+int		expand_suf_into_table P ((ichar_t * rootword,
+		  MASKTYPE mask[], int optflags,
+		  char *** exptable, int * exptsize, int numexpansions));
+static int	gen_suf_expansion P ((ichar_t * rootword,
+		  struct flagent * flent, char *** exptable, int * exptsize,
+		  int numexpansions));
 static void	forcelc P ((ichar_t * dst, int len));
 
 /* Check possible affixes */
@@ -497,19 +518,20 @@ int expand_pre (croot, rootword, mask, option, extra)
     {
     int				entcount;	/* No. of entries to process */
     int				explength;	/* Length of expansions */
-    char			exptable[MASKBITS][ICHARTOSSTR_SIZE];
-						/* Table of expansions */
+    static char **		exptable = NULL; /* Table of expansions */
+    static int			exptsize = 0;	/* Size of exptable */
+					
     register struct flagent *
 				flent;		/* Current table entry */
-    int				numexpansions;	/* Size of expansion table */
+    int				numexpansions;	/* Expansions in table now */
 
     for (flent = pflaglist, entcount = numpflags, numexpansions = 0;
       entcount > 0;
       flent++, entcount--)
 	{
 	if (TSTMASKBIT (mask, flent->flagbit))
-	    numexpansions += gen_pre_expansion (croot, rootword, flent, mask,
-	      exptable, numexpansions);
+	    numexpansions += gen_pre_expansion (rootword, flent, mask,
+	      &exptable, &exptsize, numexpansions);
 	}
     for (explength = 0;  --numexpansions >= 0;  )
 	{
@@ -523,15 +545,14 @@ int expand_pre (croot, rootword, mask, option, extra)
     }
 
 /* Generate a prefix expansion */
-static int gen_pre_expansion (croot, rootword, flent, mask, exptable,
+static int gen_pre_expansion (rootword, flent, mask, exptable, exptsize,
   numexpansions)
-    unsigned char *		croot;		/* Char version of rootword */
     register ichar_t *		rootword;	/* Root word to expand */
     register struct flagent *	flent;		/* Current table entry */
     MASKTYPE			mask[];		/* Mask bits to expand on */
-    char			exptable[MASKBITS][ICHARTOSSTR_SIZE];
-						/* Table of expansions */
-    int				numexpansions;	/* Size of expansion table */
+    char ***			exptable;	/* Ptr to tbl of expansions */
+    int *			exptsize;	/* Max size of expansion tbl */
+    int				numexpansions;	/* Expansions in table now */
     {
     int				cond;		/* Current condition number */
     int				expno;		/* Expansion # being checked */
@@ -541,11 +562,6 @@ static int gen_pre_expansion (croot, rootword, flent, mask, exptable,
     int				tlen;		/* Length of tword */
     ichar_t			tword[INPUTWORDLEN + MAXAFFIXLEN]; /* Temp */
 
-    if (numexpansions == MASKBITS)
-	{
-	(void) fprintf (stderr, TGOOD_C_TOO_MANY_PRE);
-	return 0;
-	}
     tlen = icharlen (rootword);
     if (flent->numconds > tlen)
 	return 0;
@@ -620,21 +636,74 @@ static int gen_pre_expansion (croot, rootword, flent, mask, exptable,
     numadded = 0;
     for (expno = 0;  expno < numexpansions;  expno++)
 	{
-	if (strcmp (exptable[expno], (char *) result) == 0)
+	if (strcmp ((*exptable)[expno], (char *) result) == 0)
 	    break;
 	}
     if (expno == numexpansions)
 	{
-	(void) strcpy (exptable[numexpansions], (char *) result);
+	if (numexpansions >= *exptsize)
+	    expand_exptable(exptable, exptsize);
+	(void) strcpy ((*exptable)[numexpansions], (char *) result);
 	numadded++;
 	numexpansions++;
 	}
     if (flent->flagflags & FF_CROSSPRODUCT)
-	numadded += expand_suf_into_table (croot, tword, mask, FF_CROSSPRODUCT,
-	  exptable, numexpansions);
+	numadded += expand_suf_into_table (tword, mask, FF_CROSSPRODUCT,
+	  exptable, exptsize, numexpansions);
     return numadded;
     }
 
+/*
+ * Expand the table of suffix expansions.  If it is currently of zero
+ * size, it is turned into a minimum-sized table (currently, it's of
+ * size MASKBITS, which is good for most languages).  If it's already
+ * of nonzero size, the size is doubled.
+ */
+static void expand_exptable (exptable, exptsize)
+    char ***			exptable;	/* Table to be expanded */
+    int *			exptsize;	/* Current size of table */
+    {
+    int				i;		/* Ptr being initialized */
+    int				oldsize;	/* Previous size of table */
+    int				newsize;	/* New size to give table */
+    char *			newstrings;	/* Space for expanded strs */
+
+    oldsize = *exptsize;
+    if (oldsize == 0)
+	{
+	newsize = MASKBITS;
+	*exptable = (char **) malloc (newsize * sizeof (char *));
+	}
+    else
+	{
+	newsize = oldsize * 2;
+	*exptable =
+	  (char **) realloc ((char *) *exptable, newsize * sizeof (char *));
+	}
+    if (*exptable == NULL)
+	{
+	(void) fprintf (stderr, TGOOD_C_NO_SPACE);
+	exit (1);
+	}
+
+    /*
+     * The new table slots don't point to anything yet.  For
+     * efficiency, we'll allocate just one large block of the proper
+     * size and fill the slots with pointers to parts of it.  We can
+     * get away with that approach because we never free the memory we
+     * allocated.
+     */
+    newstrings = malloc ((newsize - oldsize) * ICHARTOSSTR_SIZE);
+    if (newstrings == NULL)
+	{
+	(void) fprintf (stderr, TGOOD_C_NO_SPACE);
+	exit (1);
+	}
+    for (i = oldsize;  i < newsize;  i++)
+	(*exptable)[i] = newstrings + (i - oldsize) * ICHARTOSSTR_SIZE;
+    *exptsize = newsize;
+    }
+
 /*
  * Expand a dictionary suffix entry
  */
@@ -647,12 +716,12 @@ int expand_suf (croot, rootword, mask, optflags, option, extra)
     unsigned char *		extra;		/* Extra info to add to line */
     {
     int				explength;	/* Length of expansions */
-    char			exptable[MASKBITS][ICHARTOSSTR_SIZE];
-						/* Table of expansions */
-    int				numexpansions;	/* Size of expansion table */
+    static char **		exptable = NULL; /* Table of expansions */
+    static int			exptsize = 0;	/* Current size of exptable */
+    int				numexpansions;	/* Expansions in table now */
 
-    numexpansions =
-      expand_suf_into_table(croot, rootword, mask, optflags, exptable, 0);
+    numexpansions = expand_suf_into_table(rootword, mask, optflags,
+      &exptable, &exptsize, 0);
     for (explength = 0;  --numexpansions >= 0;  )
 	{
 	if (option == 3)
@@ -667,15 +736,14 @@ int expand_suf (croot, rootword, mask, optflags, option, extra)
 /*
  * Expand a dictionary suffix entry and insert it into an expansion table
  */
-int expand_suf_into_table (croot, rootword, mask, optflags, exptable,
+int expand_suf_into_table (rootword, mask, optflags, exptable, exptsize,
   numexpansions)
-    unsigned char *		croot;		/* Char version of rootword */
     ichar_t *			rootword;	/* Root word to expand */
     register MASKTYPE		mask[];		/* Mask bits to expand on */
     int				optflags;	/* Affix option flags */
-    char			exptable[MASKBITS][];
-						/* Table of expansions */
-    int				numexpansions;	/* Size of expansion table */
+    char ***			exptable;	/* Table of expansions */
+    int *			exptsize;	/* Current size of table */
+    int				numexpansions;	/* Expansions in table now */
     {
     int				entcount;	/* No. of entries to process */
     register struct flagent *
@@ -691,21 +759,21 @@ int expand_suf_into_table (croot, rootword, mask, optflags, exptable,
 	    {
 	    if ((optflags & FF_CROSSPRODUCT) == 0
 	      ||  (flent->flagflags & FF_CROSSPRODUCT))
-		newexpansions += gen_suf_expansion (croot, rootword, flent,
-		  exptable, newexpansions);
+		newexpansions += gen_suf_expansion (rootword, flent,
+		  exptable, exptsize, newexpansions);
 	    }
 	}
     return newexpansions - numexpansions;
     }
 
 /* Generate a suffix expansion */
-static int gen_suf_expansion (croot, rootword, flent, exptable, numexpansions)
-    unsigned char *		croot;		/* Char version of rootword */
+static int gen_suf_expansion (rootword, flent, exptable, exptsize,
+  numexpansions)
     register ichar_t *		rootword;	/* Root word to expand */
     register struct flagent *	flent;		/* Current table entry */
-    char			exptable[MASKBITS][ICHARTOSSTR_SIZE];
-						/* Table of expansions */
-    int				numexpansions;	/* Size of expansion table */
+    char ***			exptable;	/* Table of expansions */
+    int *			exptsize;	/* Current size of table */
+    int				numexpansions;	/* Expansions in table now */
     {
     int				cond;		/* Current condition number */
     int				expno;		/* Expansion # being checked */
@@ -715,11 +783,6 @@ static int gen_suf_expansion (croot, rootword, flent, exptable, numexpansions)
     ichar_t			tword[INPUTWORDLEN + MAXAFFIXLEN]; /* Temp */
     int				wascapitalized;	/* NZ if capitalized root */
 
-    if (numexpansions == MASKBITS)
-	{
-	(void) fprintf (stderr, TGOOD_C_TOO_MANY_SUF);
-	return 0;
-	}
     tlen = icharlen (rootword);
     cond = flent->numconds;
     if (cond > tlen)
@@ -770,10 +833,12 @@ static int gen_suf_expansion (croot, rootword, flent, exptable, numexpansions)
     result = ichartosstr (tword, 1);
     for (expno = 0;  expno < numexpansions;  expno++)
 	{
-	if (strcmp (exptable[expno], (char *) result) == 0)
+	if (strcmp ((*exptable)[expno], (char *) result) == 0)
 	    return 0;
 	}
-    (void) strcpy (exptable[numexpansions], (char *) result);
+    if (numexpansions >= *exptsize)
+	expand_exptable(exptable, exptsize);
+    (void) strcpy ((*exptable)[numexpansions], (char *) result);
     return 1;
     }
 
