@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: tree.c,v 1.61 2000/08/22 10:52:25 geoff Exp $";
+    "$Id: tree.c,v 1.63 2001/07/25 21:51:46 geoff Exp $";
 #endif
 
 /*
@@ -9,7 +9,7 @@ static char Rcs_Id[] =
  * Pace Willisson, 1983
  * Hash support added by Geoff Kuenning, 1987
  *
- * Copyright 1987-1989, 1992, 1993, 1999, Geoff Kuenning, Claremont, CA
+ * Copyright 1987-1989, 1992, 1993, 1999, 2001, Geoff Kuenning, Claremont, CA
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -25,10 +25,16 @@ static char Rcs_Id[] =
  *    such.  Binary redistributions based on modified source code
  *    must be clearly marked as modified versions in the documentation
  *    and/or other materials provided with the distribution.
- * 4. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgment:
- *      This product includes software developed by Geoff Kuenning and
- *      other unpaid contributors.
+ * 4. Any web site or other electronic service that offers ispell for
+ *    download or other electronic transfer as a separate entity, in
+ *    either source or binary form, must also include a prominent statement
+ *    indicating that information about ispell can be obtained from the
+ *    following Web site URL:
+ *	http://fmg-www.cs.ucla.edu/geoff/ispell.html
+ *    If the offering service supports hyperlinks, the aforementioned
+ *    Web site must also be offered as a hyperlink.  Condition #4 does
+ *    not apply if ispell is offered only as part of a larger, aggregated
+ *    product such as a word processor or packaged operating system.
  * 5. The name of Geoff Kuenning may not be used to endorse or promote
  *    products derived from this software without specific prior
  *    written permission.
@@ -48,6 +54,12 @@ static char Rcs_Id[] =
 
 /*
  * $Log: tree.c,v $
+ * Revision 1.63  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.62  2001/07/23 20:24:04  geoff
+ * Update the copyright and the license.
+ *
  * Revision 1.61  2000/08/22 10:52:25  geoff
  * Fix some compiler warnings.
  *
