@@ -8,7 +8,7 @@
  */
 
 static char * Version_ID[] = {
-    "@(#) International Ispell Version 3.2.03 06/10/01",
+    "@(#) International Ispell Version 3.2.06 08/01/01",
     "@(#) Copyright (c), 1983, by Pace Willisson",
     "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
     "@(#) 2001, by Geoff Kuenning, Claremont, CA.  All rights reserved.",
@@ -30,10 +30,17 @@ static char * Version_ID[] = {
     "@(#)    such.  Binary redistributions based on modified source code",
     "@(#)    must be clearly marked as modified versions in the documentation",
     "@(#)    and/or other materials provided with the distribution.",
-    "@(#) 4. All advertising materials mentioning features or use of this",
-    "@(#)    software must display the following acknowledgment:",
-    "@(#)      This product includes software developed by Geoff Kuenning and",
-    "@(#)      other unpaid contributors.",
+    "@(#) 4. Any web site or other electronic service that offers ispell for",
+    "@(#)    download or other electronic transfer as a separate entity, in",
+    "@(#)    either source or binary form, must also include a prominent",
+    "@(#)    statement indicating that information about ispell can be",
+    "@(#)    obtained from the following Web site URL:",
+    "@(#)	http://fmg-www.cs.ucla.edu/geoff/ispell.html",
+    "@(#)    If the offering service supports hyperlinks, the aforementioned",
+    "@(#)    Web site must also be offered as a hyperlink.  Condition #4 does",
+    "@(#)    not apply if ispell is offered only as part of a larger,",
+    "@(#)    aggregated product such as a word processor or packaged",
+    "@(#)    operating system.",
     "@(#) 5. The name of Geoff Kuenning may not be used to endorse or promote",
     "@(#)    products derived from this software without specific prior",
     "@(#)    written permission.",
@@ -54,10 +61,25 @@ static char * Version_ID[] = {
 };
 
 static char RCS_Version_ID[] =
-    "$Id: version.h,v 1.48 2001/06/10 23:54:57 geoff Exp $";
+    "$Id: version.h,v 1.53 2001/08/01 22:16:57 geoff Exp $";
 
 /*
  * $Log: version.h,v $
+ * Revision 1.53  2001/08/01 22:16:57  geoff
+ * Bump version for new release.
+ *
+ * Revision 1.52  2001/07/25 21:51:46  geoff
+ * Minor license update.
+ *
+ * Revision 1.51  2001/07/23 22:11:08  geoff
+ * Update version for a new release.
+ *
+ * Revision 1.50  2001/07/23 20:24:04  geoff
+ * Update the license.
+ *
+ * Revision 1.49  2001/06/14 09:11:11  geoff
+ * Minor patch for compilation problems on some machines.
+ *
  * Revision 1.48  2001/06/10 23:54:57  geoff
  * Bump verson to reflect latest bug fix.
  *
